define(
//begin v1.x content
({
	widgetLabel: "Controllo ortografico batch",
	unfound: "Non trovato",
	skip: "Ignora",
	skipAll: "Ignora tutto",
	toDic: "Aggiungi al dizionario",
	suggestions: "Suggerimenti",
	replace: "Sostituisci",
	replaceWith: "Sostituisci con",
	replaceAll: "Sostituisci tutto",
	cancel: "Annulla",
	msg: "Nessun errore di ortografia trovato",
	iSkip: "Ignora",
	iSkipAll: "Ignora tutto",
	iMsg: "Nessun suggerimento ortografico"
})

//end v1.x content
);
